# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: databricks_uc_registry_messages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
from . import databricks_pb2 as databricks__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%databricks_uc_registry_messages.proto\x12\x16mlflow.ucmodelregistry\x1a\x15scalapb/scalapb.proto\x1a\x10\x64\x61tabricks.proto\"\x81\x01\n\x0fRegisteredModel\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x02 \x01(\x03\x12\x1e\n\x16last_updated_timestamp\x18\x03 \x01(\x03\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\"\xd8\x02\n\x0cModelVersion\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x03 \x01(\x03\x12\x1e\n\x16last_updated_timestamp\x18\x04 \x01(\x03\x12\x0f\n\x07user_id\x18\x05 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x0e\n\x06source\x18\x07 \x01(\t\x12\x0e\n\x06run_id\x18\x08 \x01(\t\x12\x19\n\x11run_experiment_id\x18\t \x01(\t\x12\x1e\n\x16run_tracking_server_id\x18\n \x01(\t\x12:\n\x06status\x18\x0b \x01(\x0e\x32*.mlflow.ucmodelregistry.ModelVersionStatus\x12\x16\n\x0estatus_message\x18\x0c \x01(\t\x12\x18\n\x10storage_location\x18\r \x01(\t\"\x9d\x02\n\x14TemporaryCredentials\x12\x46\n\x14\x61ws_temp_credentials\x18\x02 \x01(\x0b\x32&.mlflow.ucmodelregistry.AwsCredentialsH\x00\x12S\n\x19\x61zure_user_delegation_sas\x18\x03 \x01(\x0b\x32..mlflow.ucmodelregistry.AzureUserDelegationSASH\x00\x12@\n\x0fgcp_oauth_token\x18\x04 \x01(\x0b\x32%.mlflow.ucmodelregistry.GcpOauthTokenH\x00\x12\x17\n\x0f\x65xpiration_time\x18\x01 \x01(\x03\x42\r\n\x0b\x63redentials\"Y\n\x0e\x41wsCredentials\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\x12\x19\n\x11secret_access_key\x18\x02 \x01(\t\x12\x15\n\rsession_token\x18\x03 \x01(\t\"+\n\x16\x41zureUserDelegationSAS\x12\x11\n\tsas_token\x18\x01 \x01(\t\"$\n\rGcpOauthToken\x12\x13\n\x0boauth_token\x18\x01 \x01(\t\"\x83\x01\n\x1c\x43reateRegisteredModelRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t::\xe2?7\n5com.databricks.rpc.RPC[CreateRegisteredModelResponse]\"b\n\x1d\x43reateRegisteredModelResponse\x12\x41\n\x10registered_model\x18\x01 \x01(\x0b\x32\'.mlflow.ucmodelregistry.RegisteredModel\"\x83\x01\n\x1cUpdateRegisteredModelRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t::\xe2?7\n5com.databricks.rpc.RPC[UpdateRegisteredModelResponse]\"b\n\x1dUpdateRegisteredModelResponse\x12\x41\n\x10registered_model\x18\x01 \x01(\x0b\x32\'.mlflow.ucmodelregistry.RegisteredModel\"n\n\x1c\x44\x65leteRegisteredModelRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01::\xe2?7\n5com.databricks.rpc.RPC[DeleteRegisteredModelResponse]\"\x1f\n\x1d\x44\x65leteRegisteredModelResponse\"h\n\x19GetRegisteredModelRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01:7\xe2?4\n2com.databricks.rpc.RPC[GetRegisteredModelResponse]\"_\n\x1aGetRegisteredModelResponse\x12\x41\n\x10registered_model\x18\x01 \x01(\x0b\x32\'.mlflow.ucmodelregistry.RegisteredModel\"\x8a\x01\n\x1dSearchRegisteredModelsRequest\x12\x18\n\x0bmax_results\x18\x01 \x01(\x03:\x03\x31\x30\x30\x12\x12\n\npage_token\x18\x02 \x01(\t:;\xe2?8\n6com.databricks.rpc.RPC[SearchRegisteredModelsResponse]\"}\n\x1eSearchRegisteredModelsResponse\x12\x42\n\x11registered_models\x18\x01 \x03(\x0b\x32\'.mlflow.ucmodelregistry.RegisteredModel\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xc3\x01\n\x19\x43reateModelVersionRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x14\n\x06source\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x0e\n\x06run_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x1e\n\x16run_tracking_server_id\x18\x05 \x01(\t:7\xe2?4\n2com.databricks.rpc.RPC[CreateModelVersionResponse]\"Y\n\x1a\x43reateModelVersionResponse\x12;\n\rmodel_version\x18\x01 \x01(\x0b\x32$.mlflow.ucmodelregistry.ModelVersion\"\x94\x01\n\x19UpdateModelVersionRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x15\n\x07version\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t:7\xe2?4\n2com.databricks.rpc.RPC[UpdateModelVersionResponse]\"Y\n\x1aUpdateModelVersionResponse\x12;\n\rmodel_version\x18\x01 \x01(\x0b\x32$.mlflow.ucmodelregistry.ModelVersion\"\x7f\n\x19\x44\x65leteModelVersionRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x15\n\x07version\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01:7\xe2?4\n2com.databricks.rpc.RPC[DeleteModelVersionResponse]\"\x1c\n\x1a\x44\x65leteModelVersionResponse\"y\n\x16GetModelVersionRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x15\n\x07version\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01:4\xe2?1\n/com.databricks.rpc.RPC[GetModelVersionResponse]\"V\n\x17GetModelVersionResponse\x12;\n\rmodel_version\x18\x01 \x01(\x0b\x32$.mlflow.ucmodelregistry.ModelVersion\"\x96\x01\n\x1aSearchModelVersionsRequest\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\x12\x1a\n\x0bmax_results\x18\x02 \x01(\x03:\x05\x31\x30\x30\x30\x30\x12\x12\n\npage_token\x18\x03 \x01(\t:8\xe2?5\n3com.databricks.rpc.RPC[SearchModelVersionsResponse]\"t\n\x1bSearchModelVersionsResponse\x12<\n\x0emodel_versions\x18\x01 \x03(\x0b\x32$.mlflow.ucmodelregistry.ModelVersion\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xf3\x01\n/GenerateTemporaryModelVersionCredentialsRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x15\n\x07version\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x46\n\toperation\x18\x03 \x01(\x0e\x32-.mlflow.ucmodelregistry.ModelVersionOperationB\x04\xf8\x86\x19\x01:M\xe2?J\nHcom.databricks.rpc.RPC[GenerateTemporaryModelVersionCredentialsResponse]\"u\n0GenerateTemporaryModelVersionCredentialsResponse\x12\x41\n\x0b\x63redentials\x18\x01 \x01(\x0b\x32,.mlflow.ucmodelregistry.TemporaryCredentials\"\x8f\x01\n!GetModelVersionDownloadUriRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x15\n\x07version\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01:?\xe2?<\n:com.databricks.rpc.RPC[GetModelVersionDownloadUriResponse]\":\n\"GetModelVersionDownloadUriResponse\x12\x14\n\x0c\x61rtifact_uri\x18\x01 \x01(\t\"\x83\x01\n\x1b\x46inalizeModelVersionRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x15\n\x07version\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01:9\xe2?6\n4com.databricks.rpc.RPC[FinalizeModelVersionResponse]\"[\n\x1c\x46inalizeModelVersionResponse\x12;\n\rmodel_version\x18\x01 \x01(\x0b\x32$.mlflow.ucmodelregistry.ModelVersion\"\x9e\x01\n\x1eSetRegisteredModelAliasRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x13\n\x05\x61lias\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01\x12\x15\n\x07version\x18\x03 \x01(\tB\x04\xf8\x86\x19\x01:<\xe2?9\n7com.databricks.rpc.RPC[SetRegisteredModelAliasResponse]\"!\n\x1fSetRegisteredModelAliasResponse\"\x8d\x01\n!DeleteRegisteredModelAliasRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x13\n\x05\x61lias\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01:?\xe2?<\n:com.databricks.rpc.RPC[DeleteRegisteredModelAliasResponse]\"$\n\"DeleteRegisteredModelAliasResponse\"\x85\x01\n\x1dGetModelVersionByAliasRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xf8\x86\x19\x01\x12\x13\n\x05\x61lias\x18\x02 \x01(\tB\x04\xf8\x86\x19\x01:;\xe2?8\n6com.databricks.rpc.RPC[GetModelVersionByAliasResponse]\"]\n\x1eGetModelVersionByAliasResponse\x12;\n\rmodel_version\x18\x01 \x01(\x0b\x32$.mlflow.ucmodelregistry.ModelVersion*c\n\x12ModelVersionStatus\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x18\n\x14PENDING_REGISTRATION\x10\x01\x12\x17\n\x13\x46\x41ILED_REGISTRATION\x10\x02\x12\t\n\x05READY\x10\x03*\x8a\x01\n\x15ModelVersionOperation\x12\'\n#MODEL_VERSION_OPERATION_UNSPECIFIED\x10\x00\x12 \n\x1cMODEL_VERSION_OPERATION_READ\x10\x01\x12&\n\"MODEL_VERSION_OPERATION_READ_WRITE\x10\x02\x42\x32\n(com.databricks.api.proto.ucmodelregistry\xa0\x01\x01\xe2?\x02\x10\x01')

_MODELVERSIONSTATUS = DESCRIPTOR.enum_types_by_name['ModelVersionStatus']
ModelVersionStatus = enum_type_wrapper.EnumTypeWrapper(_MODELVERSIONSTATUS)
_MODELVERSIONOPERATION = DESCRIPTOR.enum_types_by_name['ModelVersionOperation']
ModelVersionOperation = enum_type_wrapper.EnumTypeWrapper(_MODELVERSIONOPERATION)
UNSPECIFIED = 0
PENDING_REGISTRATION = 1
FAILED_REGISTRATION = 2
READY = 3
MODEL_VERSION_OPERATION_UNSPECIFIED = 0
MODEL_VERSION_OPERATION_READ = 1
MODEL_VERSION_OPERATION_READ_WRITE = 2


_REGISTEREDMODEL = DESCRIPTOR.message_types_by_name['RegisteredModel']
_MODELVERSION = DESCRIPTOR.message_types_by_name['ModelVersion']
_TEMPORARYCREDENTIALS = DESCRIPTOR.message_types_by_name['TemporaryCredentials']
_AWSCREDENTIALS = DESCRIPTOR.message_types_by_name['AwsCredentials']
_AZUREUSERDELEGATIONSAS = DESCRIPTOR.message_types_by_name['AzureUserDelegationSAS']
_GCPOAUTHTOKEN = DESCRIPTOR.message_types_by_name['GcpOauthToken']
_CREATEREGISTEREDMODELREQUEST = DESCRIPTOR.message_types_by_name['CreateRegisteredModelRequest']
_CREATEREGISTEREDMODELRESPONSE = DESCRIPTOR.message_types_by_name['CreateRegisteredModelResponse']
_UPDATEREGISTEREDMODELREQUEST = DESCRIPTOR.message_types_by_name['UpdateRegisteredModelRequest']
_UPDATEREGISTEREDMODELRESPONSE = DESCRIPTOR.message_types_by_name['UpdateRegisteredModelResponse']
_DELETEREGISTEREDMODELREQUEST = DESCRIPTOR.message_types_by_name['DeleteRegisteredModelRequest']
_DELETEREGISTEREDMODELRESPONSE = DESCRIPTOR.message_types_by_name['DeleteRegisteredModelResponse']
_GETREGISTEREDMODELREQUEST = DESCRIPTOR.message_types_by_name['GetRegisteredModelRequest']
_GETREGISTEREDMODELRESPONSE = DESCRIPTOR.message_types_by_name['GetRegisteredModelResponse']
_SEARCHREGISTEREDMODELSREQUEST = DESCRIPTOR.message_types_by_name['SearchRegisteredModelsRequest']
_SEARCHREGISTEREDMODELSRESPONSE = DESCRIPTOR.message_types_by_name['SearchRegisteredModelsResponse']
_CREATEMODELVERSIONREQUEST = DESCRIPTOR.message_types_by_name['CreateModelVersionRequest']
_CREATEMODELVERSIONRESPONSE = DESCRIPTOR.message_types_by_name['CreateModelVersionResponse']
_UPDATEMODELVERSIONREQUEST = DESCRIPTOR.message_types_by_name['UpdateModelVersionRequest']
_UPDATEMODELVERSIONRESPONSE = DESCRIPTOR.message_types_by_name['UpdateModelVersionResponse']
_DELETEMODELVERSIONREQUEST = DESCRIPTOR.message_types_by_name['DeleteModelVersionRequest']
_DELETEMODELVERSIONRESPONSE = DESCRIPTOR.message_types_by_name['DeleteModelVersionResponse']
_GETMODELVERSIONREQUEST = DESCRIPTOR.message_types_by_name['GetModelVersionRequest']
_GETMODELVERSIONRESPONSE = DESCRIPTOR.message_types_by_name['GetModelVersionResponse']
_SEARCHMODELVERSIONSREQUEST = DESCRIPTOR.message_types_by_name['SearchModelVersionsRequest']
_SEARCHMODELVERSIONSRESPONSE = DESCRIPTOR.message_types_by_name['SearchModelVersionsResponse']
_GENERATETEMPORARYMODELVERSIONCREDENTIALSREQUEST = DESCRIPTOR.message_types_by_name['GenerateTemporaryModelVersionCredentialsRequest']
_GENERATETEMPORARYMODELVERSIONCREDENTIALSRESPONSE = DESCRIPTOR.message_types_by_name['GenerateTemporaryModelVersionCredentialsResponse']
_GETMODELVERSIONDOWNLOADURIREQUEST = DESCRIPTOR.message_types_by_name['GetModelVersionDownloadUriRequest']
_GETMODELVERSIONDOWNLOADURIRESPONSE = DESCRIPTOR.message_types_by_name['GetModelVersionDownloadUriResponse']
_FINALIZEMODELVERSIONREQUEST = DESCRIPTOR.message_types_by_name['FinalizeModelVersionRequest']
_FINALIZEMODELVERSIONRESPONSE = DESCRIPTOR.message_types_by_name['FinalizeModelVersionResponse']
_SETREGISTEREDMODELALIASREQUEST = DESCRIPTOR.message_types_by_name['SetRegisteredModelAliasRequest']
_SETREGISTEREDMODELALIASRESPONSE = DESCRIPTOR.message_types_by_name['SetRegisteredModelAliasResponse']
_DELETEREGISTEREDMODELALIASREQUEST = DESCRIPTOR.message_types_by_name['DeleteRegisteredModelAliasRequest']
_DELETEREGISTEREDMODELALIASRESPONSE = DESCRIPTOR.message_types_by_name['DeleteRegisteredModelAliasResponse']
_GETMODELVERSIONBYALIASREQUEST = DESCRIPTOR.message_types_by_name['GetModelVersionByAliasRequest']
_GETMODELVERSIONBYALIASRESPONSE = DESCRIPTOR.message_types_by_name['GetModelVersionByAliasResponse']
RegisteredModel = _reflection.GeneratedProtocolMessageType('RegisteredModel', (_message.Message,), {
  'DESCRIPTOR' : _REGISTEREDMODEL,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.RegisteredModel)
  })
_sym_db.RegisterMessage(RegisteredModel)

ModelVersion = _reflection.GeneratedProtocolMessageType('ModelVersion', (_message.Message,), {
  'DESCRIPTOR' : _MODELVERSION,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.ModelVersion)
  })
_sym_db.RegisterMessage(ModelVersion)

TemporaryCredentials = _reflection.GeneratedProtocolMessageType('TemporaryCredentials', (_message.Message,), {
  'DESCRIPTOR' : _TEMPORARYCREDENTIALS,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.TemporaryCredentials)
  })
_sym_db.RegisterMessage(TemporaryCredentials)

AwsCredentials = _reflection.GeneratedProtocolMessageType('AwsCredentials', (_message.Message,), {
  'DESCRIPTOR' : _AWSCREDENTIALS,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.AwsCredentials)
  })
_sym_db.RegisterMessage(AwsCredentials)

AzureUserDelegationSAS = _reflection.GeneratedProtocolMessageType('AzureUserDelegationSAS', (_message.Message,), {
  'DESCRIPTOR' : _AZUREUSERDELEGATIONSAS,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.AzureUserDelegationSAS)
  })
_sym_db.RegisterMessage(AzureUserDelegationSAS)

GcpOauthToken = _reflection.GeneratedProtocolMessageType('GcpOauthToken', (_message.Message,), {
  'DESCRIPTOR' : _GCPOAUTHTOKEN,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.GcpOauthToken)
  })
_sym_db.RegisterMessage(GcpOauthToken)

CreateRegisteredModelRequest = _reflection.GeneratedProtocolMessageType('CreateRegisteredModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREGISTEREDMODELREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.CreateRegisteredModelRequest)
  })
_sym_db.RegisterMessage(CreateRegisteredModelRequest)

CreateRegisteredModelResponse = _reflection.GeneratedProtocolMessageType('CreateRegisteredModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEREGISTEREDMODELRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.CreateRegisteredModelResponse)
  })
_sym_db.RegisterMessage(CreateRegisteredModelResponse)

UpdateRegisteredModelRequest = _reflection.GeneratedProtocolMessageType('UpdateRegisteredModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREGISTEREDMODELREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.UpdateRegisteredModelRequest)
  })
_sym_db.RegisterMessage(UpdateRegisteredModelRequest)

UpdateRegisteredModelResponse = _reflection.GeneratedProtocolMessageType('UpdateRegisteredModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREGISTEREDMODELRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.UpdateRegisteredModelResponse)
  })
_sym_db.RegisterMessage(UpdateRegisteredModelResponse)

DeleteRegisteredModelRequest = _reflection.GeneratedProtocolMessageType('DeleteRegisteredModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREGISTEREDMODELREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.DeleteRegisteredModelRequest)
  })
_sym_db.RegisterMessage(DeleteRegisteredModelRequest)

DeleteRegisteredModelResponse = _reflection.GeneratedProtocolMessageType('DeleteRegisteredModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREGISTEREDMODELRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.DeleteRegisteredModelResponse)
  })
_sym_db.RegisterMessage(DeleteRegisteredModelResponse)

GetRegisteredModelRequest = _reflection.GeneratedProtocolMessageType('GetRegisteredModelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREGISTEREDMODELREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.GetRegisteredModelRequest)
  })
_sym_db.RegisterMessage(GetRegisteredModelRequest)

GetRegisteredModelResponse = _reflection.GeneratedProtocolMessageType('GetRegisteredModelResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETREGISTEREDMODELRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.GetRegisteredModelResponse)
  })
_sym_db.RegisterMessage(GetRegisteredModelResponse)

SearchRegisteredModelsRequest = _reflection.GeneratedProtocolMessageType('SearchRegisteredModelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHREGISTEREDMODELSREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.SearchRegisteredModelsRequest)
  })
_sym_db.RegisterMessage(SearchRegisteredModelsRequest)

SearchRegisteredModelsResponse = _reflection.GeneratedProtocolMessageType('SearchRegisteredModelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHREGISTEREDMODELSRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.SearchRegisteredModelsResponse)
  })
_sym_db.RegisterMessage(SearchRegisteredModelsResponse)

CreateModelVersionRequest = _reflection.GeneratedProtocolMessageType('CreateModelVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELVERSIONREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.CreateModelVersionRequest)
  })
_sym_db.RegisterMessage(CreateModelVersionRequest)

CreateModelVersionResponse = _reflection.GeneratedProtocolMessageType('CreateModelVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMODELVERSIONRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.CreateModelVersionResponse)
  })
_sym_db.RegisterMessage(CreateModelVersionResponse)

UpdateModelVersionRequest = _reflection.GeneratedProtocolMessageType('UpdateModelVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELVERSIONREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.UpdateModelVersionRequest)
  })
_sym_db.RegisterMessage(UpdateModelVersionRequest)

UpdateModelVersionResponse = _reflection.GeneratedProtocolMessageType('UpdateModelVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEMODELVERSIONRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.UpdateModelVersionResponse)
  })
_sym_db.RegisterMessage(UpdateModelVersionResponse)

DeleteModelVersionRequest = _reflection.GeneratedProtocolMessageType('DeleteModelVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELVERSIONREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.DeleteModelVersionRequest)
  })
_sym_db.RegisterMessage(DeleteModelVersionRequest)

DeleteModelVersionResponse = _reflection.GeneratedProtocolMessageType('DeleteModelVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMODELVERSIONRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.DeleteModelVersionResponse)
  })
_sym_db.RegisterMessage(DeleteModelVersionResponse)

GetModelVersionRequest = _reflection.GeneratedProtocolMessageType('GetModelVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELVERSIONREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.GetModelVersionRequest)
  })
_sym_db.RegisterMessage(GetModelVersionRequest)

GetModelVersionResponse = _reflection.GeneratedProtocolMessageType('GetModelVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELVERSIONRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.GetModelVersionResponse)
  })
_sym_db.RegisterMessage(GetModelVersionResponse)

SearchModelVersionsRequest = _reflection.GeneratedProtocolMessageType('SearchModelVersionsRequest', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHMODELVERSIONSREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.SearchModelVersionsRequest)
  })
_sym_db.RegisterMessage(SearchModelVersionsRequest)

SearchModelVersionsResponse = _reflection.GeneratedProtocolMessageType('SearchModelVersionsResponse', (_message.Message,), {
  'DESCRIPTOR' : _SEARCHMODELVERSIONSRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.SearchModelVersionsResponse)
  })
_sym_db.RegisterMessage(SearchModelVersionsResponse)

GenerateTemporaryModelVersionCredentialsRequest = _reflection.GeneratedProtocolMessageType('GenerateTemporaryModelVersionCredentialsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETEMPORARYMODELVERSIONCREDENTIALSREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.GenerateTemporaryModelVersionCredentialsRequest)
  })
_sym_db.RegisterMessage(GenerateTemporaryModelVersionCredentialsRequest)

GenerateTemporaryModelVersionCredentialsResponse = _reflection.GeneratedProtocolMessageType('GenerateTemporaryModelVersionCredentialsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETEMPORARYMODELVERSIONCREDENTIALSRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.GenerateTemporaryModelVersionCredentialsResponse)
  })
_sym_db.RegisterMessage(GenerateTemporaryModelVersionCredentialsResponse)

GetModelVersionDownloadUriRequest = _reflection.GeneratedProtocolMessageType('GetModelVersionDownloadUriRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELVERSIONDOWNLOADURIREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.GetModelVersionDownloadUriRequest)
  })
_sym_db.RegisterMessage(GetModelVersionDownloadUriRequest)

GetModelVersionDownloadUriResponse = _reflection.GeneratedProtocolMessageType('GetModelVersionDownloadUriResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELVERSIONDOWNLOADURIRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.GetModelVersionDownloadUriResponse)
  })
_sym_db.RegisterMessage(GetModelVersionDownloadUriResponse)

FinalizeModelVersionRequest = _reflection.GeneratedProtocolMessageType('FinalizeModelVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _FINALIZEMODELVERSIONREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.FinalizeModelVersionRequest)
  })
_sym_db.RegisterMessage(FinalizeModelVersionRequest)

FinalizeModelVersionResponse = _reflection.GeneratedProtocolMessageType('FinalizeModelVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _FINALIZEMODELVERSIONRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.FinalizeModelVersionResponse)
  })
_sym_db.RegisterMessage(FinalizeModelVersionResponse)

SetRegisteredModelAliasRequest = _reflection.GeneratedProtocolMessageType('SetRegisteredModelAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETREGISTEREDMODELALIASREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.SetRegisteredModelAliasRequest)
  })
_sym_db.RegisterMessage(SetRegisteredModelAliasRequest)

SetRegisteredModelAliasResponse = _reflection.GeneratedProtocolMessageType('SetRegisteredModelAliasResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETREGISTEREDMODELALIASRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.SetRegisteredModelAliasResponse)
  })
_sym_db.RegisterMessage(SetRegisteredModelAliasResponse)

DeleteRegisteredModelAliasRequest = _reflection.GeneratedProtocolMessageType('DeleteRegisteredModelAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREGISTEREDMODELALIASREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.DeleteRegisteredModelAliasRequest)
  })
_sym_db.RegisterMessage(DeleteRegisteredModelAliasRequest)

DeleteRegisteredModelAliasResponse = _reflection.GeneratedProtocolMessageType('DeleteRegisteredModelAliasResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEREGISTEREDMODELALIASRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.DeleteRegisteredModelAliasResponse)
  })
_sym_db.RegisterMessage(DeleteRegisteredModelAliasResponse)

GetModelVersionByAliasRequest = _reflection.GeneratedProtocolMessageType('GetModelVersionByAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELVERSIONBYALIASREQUEST,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.GetModelVersionByAliasRequest)
  })
_sym_db.RegisterMessage(GetModelVersionByAliasRequest)

GetModelVersionByAliasResponse = _reflection.GeneratedProtocolMessageType('GetModelVersionByAliasResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMODELVERSIONBYALIASRESPONSE,
  '__module__' : 'databricks_uc_registry_messages_pb2'
  # @@protoc_insertion_point(class_scope:mlflow.ucmodelregistry.GetModelVersionByAliasResponse)
  })
_sym_db.RegisterMessage(GetModelVersionByAliasResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(com.databricks.api.proto.ucmodelregistry\240\001\001\342?\002\020\001'
  _CREATEREGISTEREDMODELREQUEST.fields_by_name['name']._options = None
  _CREATEREGISTEREDMODELREQUEST.fields_by_name['name']._serialized_options = b'\370\206\031\001'
  _CREATEREGISTEREDMODELREQUEST._options = None
  _CREATEREGISTEREDMODELREQUEST._serialized_options = b'\342?7\n5com.databricks.rpc.RPC[CreateRegisteredModelResponse]'
  _UPDATEREGISTEREDMODELREQUEST.fields_by_name['name']._options = None
  _UPDATEREGISTEREDMODELREQUEST.fields_by_name['name']._serialized_options = b'\370\206\031\001'
  _UPDATEREGISTEREDMODELREQUEST._options = None
  _UPDATEREGISTEREDMODELREQUEST._serialized_options = b'\342?7\n5com.databricks.rpc.RPC[UpdateRegisteredModelResponse]'
  _DELETEREGISTEREDMODELREQUEST.fields_by_name['name']._options = None
  _DELETEREGISTEREDMODELREQUEST.fields_by_name['name']._serialized_options = b'\370\206\031\001'
  _DELETEREGISTEREDMODELREQUEST._options = None
  _DELETEREGISTEREDMODELREQUEST._serialized_options = b'\342?7\n5com.databricks.rpc.RPC[DeleteRegisteredModelResponse]'
  _GETREGISTEREDMODELREQUEST.fields_by_name['name']._options = None
  _GETREGISTEREDMODELREQUEST.fields_by_name['name']._serialized_options = b'\370\206\031\001'
  _GETREGISTEREDMODELREQUEST._options = None
  _GETREGISTEREDMODELREQUEST._serialized_options = b'\342?4\n2com.databricks.rpc.RPC[GetRegisteredModelResponse]'
  _SEARCHREGISTEREDMODELSREQUEST._options = None
  _SEARCHREGISTEREDMODELSREQUEST._serialized_options = b'\342?8\n6com.databricks.rpc.RPC[SearchRegisteredModelsResponse]'
  _CREATEMODELVERSIONREQUEST.fields_by_name['name']._options = None
  _CREATEMODELVERSIONREQUEST.fields_by_name['name']._serialized_options = b'\370\206\031\001'
  _CREATEMODELVERSIONREQUEST.fields_by_name['source']._options = None
  _CREATEMODELVERSIONREQUEST.fields_by_name['source']._serialized_options = b'\370\206\031\001'
  _CREATEMODELVERSIONREQUEST._options = None
  _CREATEMODELVERSIONREQUEST._serialized_options = b'\342?4\n2com.databricks.rpc.RPC[CreateModelVersionResponse]'
  _UPDATEMODELVERSIONREQUEST.fields_by_name['name']._options = None
  _UPDATEMODELVERSIONREQUEST.fields_by_name['name']._serialized_options = b'\370\206\031\001'
  _UPDATEMODELVERSIONREQUEST.fields_by_name['version']._options = None
  _UPDATEMODELVERSIONREQUEST.fields_by_name['version']._serialized_options = b'\370\206\031\001'
  _UPDATEMODELVERSIONREQUEST._options = None
  _UPDATEMODELVERSIONREQUEST._serialized_options = b'\342?4\n2com.databricks.rpc.RPC[UpdateModelVersionResponse]'
  _DELETEMODELVERSIONREQUEST.fields_by_name['name']._options = None
  _DELETEMODELVERSIONREQUEST.fields_by_name['name']._serialized_options = b'\370\206\031\001'
  _DELETEMODELVERSIONREQUEST.fields_by_name['version']._options = None
  _DELETEMODELVERSIONREQUEST.fields_by_name['version']._serialized_options = b'\370\206\031\001'
  _DELETEMODELVERSIONREQUEST._options = None
  _DELETEMODELVERSIONREQUEST._serialized_options = b'\342?4\n2com.databricks.rpc.RPC[DeleteModelVersionResponse]'
  _GETMODELVERSIONREQUEST.fields_by_name['name']._options = None
  _GETMODELVERSIONREQUEST.fields_by_name['name']._serialized_options = b'\370\206\031\001'
  _GETMODELVERSIONREQUEST.fields_by_name['version']._options = None
  _GETMODELVERSIONREQUEST.fields_by_name['version']._serialized_options = b'\370\206\031\001'
  _GETMODELVERSIONREQUEST._options = None
  _GETMODELVERSIONREQUEST._serialized_options = b'\342?1\n/com.databricks.rpc.RPC[GetModelVersionResponse]'
  _SEARCHMODELVERSIONSREQUEST._options = None
  _SEARCHMODELVERSIONSREQUEST._serialized_options = b'\342?5\n3com.databricks.rpc.RPC[SearchModelVersionsResponse]'
  _GENERATETEMPORARYMODELVERSIONCREDENTIALSREQUEST.fields_by_name['name']._options = None
  _GENERATETEMPORARYMODELVERSIONCREDENTIALSREQUEST.fields_by_name['name']._serialized_options = b'\370\206\031\001'
  _GENERATETEMPORARYMODELVERSIONCREDENTIALSREQUEST.fields_by_name['version']._options = None
  _GENERATETEMPORARYMODELVERSIONCREDENTIALSREQUEST.fields_by_name['version']._serialized_options = b'\370\206\031\001'
  _GENERATETEMPORARYMODELVERSIONCREDENTIALSREQUEST.fields_by_name['operation']._options = None
  _GENERATETEMPORARYMODELVERSIONCREDENTIALSREQUEST.fields_by_name['operation']._serialized_options = b'\370\206\031\001'
  _GENERATETEMPORARYMODELVERSIONCREDENTIALSREQUEST._options = None
  _GENERATETEMPORARYMODELVERSIONCREDENTIALSREQUEST._serialized_options = b'\342?J\nHcom.databricks.rpc.RPC[GenerateTemporaryModelVersionCredentialsResponse]'
  _GETMODELVERSIONDOWNLOADURIREQUEST.fields_by_name['name']._options = None
  _GETMODELVERSIONDOWNLOADURIREQUEST.fields_by_name['name']._serialized_options = b'\370\206\031\001'
  _GETMODELVERSIONDOWNLOADURIREQUEST.fields_by_name['version']._options = None
  _GETMODELVERSIONDOWNLOADURIREQUEST.fields_by_name['version']._serialized_options = b'\370\206\031\001'
  _GETMODELVERSIONDOWNLOADURIREQUEST._options = None
  _GETMODELVERSIONDOWNLOADURIREQUEST._serialized_options = b'\342?<\n:com.databricks.rpc.RPC[GetModelVersionDownloadUriResponse]'
  _FINALIZEMODELVERSIONREQUEST.fields_by_name['name']._options = None
  _FINALIZEMODELVERSIONREQUEST.fields_by_name['name']._serialized_options = b'\370\206\031\001'
  _FINALIZEMODELVERSIONREQUEST.fields_by_name['version']._options = None
  _FINALIZEMODELVERSIONREQUEST.fields_by_name['version']._serialized_options = b'\370\206\031\001'
  _FINALIZEMODELVERSIONREQUEST._options = None
  _FINALIZEMODELVERSIONREQUEST._serialized_options = b'\342?6\n4com.databricks.rpc.RPC[FinalizeModelVersionResponse]'
  _SETREGISTEREDMODELALIASREQUEST.fields_by_name['name']._options = None
  _SETREGISTEREDMODELALIASREQUEST.fields_by_name['name']._serialized_options = b'\370\206\031\001'
  _SETREGISTEREDMODELALIASREQUEST.fields_by_name['alias']._options = None
  _SETREGISTEREDMODELALIASREQUEST.fields_by_name['alias']._serialized_options = b'\370\206\031\001'
  _SETREGISTEREDMODELALIASREQUEST.fields_by_name['version']._options = None
  _SETREGISTEREDMODELALIASREQUEST.fields_by_name['version']._serialized_options = b'\370\206\031\001'
  _SETREGISTEREDMODELALIASREQUEST._options = None
  _SETREGISTEREDMODELALIASREQUEST._serialized_options = b'\342?9\n7com.databricks.rpc.RPC[SetRegisteredModelAliasResponse]'
  _DELETEREGISTEREDMODELALIASREQUEST.fields_by_name['name']._options = None
  _DELETEREGISTEREDMODELALIASREQUEST.fields_by_name['name']._serialized_options = b'\370\206\031\001'
  _DELETEREGISTEREDMODELALIASREQUEST.fields_by_name['alias']._options = None
  _DELETEREGISTEREDMODELALIASREQUEST.fields_by_name['alias']._serialized_options = b'\370\206\031\001'
  _DELETEREGISTEREDMODELALIASREQUEST._options = None
  _DELETEREGISTEREDMODELALIASREQUEST._serialized_options = b'\342?<\n:com.databricks.rpc.RPC[DeleteRegisteredModelAliasResponse]'
  _GETMODELVERSIONBYALIASREQUEST.fields_by_name['name']._options = None
  _GETMODELVERSIONBYALIASREQUEST.fields_by_name['name']._serialized_options = b'\370\206\031\001'
  _GETMODELVERSIONBYALIASREQUEST.fields_by_name['alias']._options = None
  _GETMODELVERSIONBYALIASREQUEST.fields_by_name['alias']._serialized_options = b'\370\206\031\001'
  _GETMODELVERSIONBYALIASREQUEST._options = None
  _GETMODELVERSIONBYALIASREQUEST._serialized_options = b'\342?8\n6com.databricks.rpc.RPC[GetModelVersionByAliasResponse]'
  _MODELVERSIONSTATUS._serialized_start=4710
  _MODELVERSIONSTATUS._serialized_end=4809
  _MODELVERSIONOPERATION._serialized_start=4812
  _MODELVERSIONOPERATION._serialized_end=4950
  _REGISTEREDMODEL._serialized_start=107
  _REGISTEREDMODEL._serialized_end=236
  _MODELVERSION._serialized_start=239
  _MODELVERSION._serialized_end=583
  _TEMPORARYCREDENTIALS._serialized_start=586
  _TEMPORARYCREDENTIALS._serialized_end=871
  _AWSCREDENTIALS._serialized_start=873
  _AWSCREDENTIALS._serialized_end=962
  _AZUREUSERDELEGATIONSAS._serialized_start=964
  _AZUREUSERDELEGATIONSAS._serialized_end=1007
  _GCPOAUTHTOKEN._serialized_start=1009
  _GCPOAUTHTOKEN._serialized_end=1045
  _CREATEREGISTEREDMODELREQUEST._serialized_start=1048
  _CREATEREGISTEREDMODELREQUEST._serialized_end=1179
  _CREATEREGISTEREDMODELRESPONSE._serialized_start=1181
  _CREATEREGISTEREDMODELRESPONSE._serialized_end=1279
  _UPDATEREGISTEREDMODELREQUEST._serialized_start=1282
  _UPDATEREGISTEREDMODELREQUEST._serialized_end=1413
  _UPDATEREGISTEREDMODELRESPONSE._serialized_start=1415
  _UPDATEREGISTEREDMODELRESPONSE._serialized_end=1513
  _DELETEREGISTEREDMODELREQUEST._serialized_start=1515
  _DELETEREGISTEREDMODELREQUEST._serialized_end=1625
  _DELETEREGISTEREDMODELRESPONSE._serialized_start=1627
  _DELETEREGISTEREDMODELRESPONSE._serialized_end=1658
  _GETREGISTEREDMODELREQUEST._serialized_start=1660
  _GETREGISTEREDMODELREQUEST._serialized_end=1764
  _GETREGISTEREDMODELRESPONSE._serialized_start=1766
  _GETREGISTEREDMODELRESPONSE._serialized_end=1861
  _SEARCHREGISTEREDMODELSREQUEST._serialized_start=1864
  _SEARCHREGISTEREDMODELSREQUEST._serialized_end=2002
  _SEARCHREGISTEREDMODELSRESPONSE._serialized_start=2004
  _SEARCHREGISTEREDMODELSRESPONSE._serialized_end=2129
  _CREATEMODELVERSIONREQUEST._serialized_start=2132
  _CREATEMODELVERSIONREQUEST._serialized_end=2327
  _CREATEMODELVERSIONRESPONSE._serialized_start=2329
  _CREATEMODELVERSIONRESPONSE._serialized_end=2418
  _UPDATEMODELVERSIONREQUEST._serialized_start=2421
  _UPDATEMODELVERSIONREQUEST._serialized_end=2569
  _UPDATEMODELVERSIONRESPONSE._serialized_start=2571
  _UPDATEMODELVERSIONRESPONSE._serialized_end=2660
  _DELETEMODELVERSIONREQUEST._serialized_start=2662
  _DELETEMODELVERSIONREQUEST._serialized_end=2789
  _DELETEMODELVERSIONRESPONSE._serialized_start=2791
  _DELETEMODELVERSIONRESPONSE._serialized_end=2819
  _GETMODELVERSIONREQUEST._serialized_start=2821
  _GETMODELVERSIONREQUEST._serialized_end=2942
  _GETMODELVERSIONRESPONSE._serialized_start=2944
  _GETMODELVERSIONRESPONSE._serialized_end=3030
  _SEARCHMODELVERSIONSREQUEST._serialized_start=3033
  _SEARCHMODELVERSIONSREQUEST._serialized_end=3183
  _SEARCHMODELVERSIONSRESPONSE._serialized_start=3185
  _SEARCHMODELVERSIONSRESPONSE._serialized_end=3301
  _GENERATETEMPORARYMODELVERSIONCREDENTIALSREQUEST._serialized_start=3304
  _GENERATETEMPORARYMODELVERSIONCREDENTIALSREQUEST._serialized_end=3547
  _GENERATETEMPORARYMODELVERSIONCREDENTIALSRESPONSE._serialized_start=3549
  _GENERATETEMPORARYMODELVERSIONCREDENTIALSRESPONSE._serialized_end=3666
  _GETMODELVERSIONDOWNLOADURIREQUEST._serialized_start=3669
  _GETMODELVERSIONDOWNLOADURIREQUEST._serialized_end=3812
  _GETMODELVERSIONDOWNLOADURIRESPONSE._serialized_start=3814
  _GETMODELVERSIONDOWNLOADURIRESPONSE._serialized_end=3872
  _FINALIZEMODELVERSIONREQUEST._serialized_start=3875
  _FINALIZEMODELVERSIONREQUEST._serialized_end=4006
  _FINALIZEMODELVERSIONRESPONSE._serialized_start=4008
  _FINALIZEMODELVERSIONRESPONSE._serialized_end=4099
  _SETREGISTEREDMODELALIASREQUEST._serialized_start=4102
  _SETREGISTEREDMODELALIASREQUEST._serialized_end=4260
  _SETREGISTEREDMODELALIASRESPONSE._serialized_start=4262
  _SETREGISTEREDMODELALIASRESPONSE._serialized_end=4295
  _DELETEREGISTEREDMODELALIASREQUEST._serialized_start=4298
  _DELETEREGISTEREDMODELALIASREQUEST._serialized_end=4439
  _DELETEREGISTEREDMODELALIASRESPONSE._serialized_start=4441
  _DELETEREGISTEREDMODELALIASRESPONSE._serialized_end=4477
  _GETMODELVERSIONBYALIASREQUEST._serialized_start=4480
  _GETMODELVERSIONBYALIASREQUEST._serialized_end=4613
  _GETMODELVERSIONBYALIASRESPONSE._serialized_start=4615
  _GETMODELVERSIONBYALIASRESPONSE._serialized_end=4708
# @@protoc_insertion_point(module_scope)



"""
This module provides a set of utilities for interpreting and creating requirements files
(e.g. pip's `requirements.txt`), which is useful for managing ML software environments.
"""

import json
import sys
import subprocess
from threading import Timer
import tempfile
import os
import pkg_resources
import importlib_metadata
from itertools import filterfalse, chain
from collections import namedtuple
import logging
import re
from typing import NamedTuple, Optional
from pathlib import Path

import mlflow
from mlflow.environment_variables import MLFLOW_REQUIREMENTS_INFERENCE_TIMEOUT
from mlflow.exceptions import MlflowException
from mlflow.tracking.artifact_utils import _download_artifact_from_uri
from mlflow.utils.autologging_utils.versioning import _strip_dev_version_suffix
from mlflow.utils.databricks_utils import is_in_databricks_runtime
from packaging.version import Version, InvalidVersion

_logger = logging.getLogger(__name__)


def _is_comment(line):
    return line.startswith("#")


def _is_empty(line):
    return line == ""


def _strip_inline_comment(line):
    return line[: line.find(" #")].rstrip() if " #" in line else line


def _is_requirements_file(line):
    return line.startswith("-r ") or line.startswith("--requirement ")


def _is_constraints_file(line):
    return line.startswith("-c ") or line.startswith("--constraint ")


def _join_continued_lines(lines):
    """
    Joins lines ending with '\\'.

    >>> _join_continued_lines["a\\", "b\\", "c"]
    >>> 'abc'
    """
    continued_lines = []

    for line in lines:
        if line.endswith("\\"):
            continued_lines.append(line.rstrip("\\"))
        else:
            continued_lines.append(line)
            yield "".join(continued_lines)
            continued_lines.clear()

    # The last line ends with '\'
    if continued_lines:
        yield "".join(continued_lines)


# Represents a pip requirement.
#
# :param req_str: A requirement string (e.g. "scikit-learn == 0.24.2").
# :param is_constraint: A boolean indicating whether this requirement is a constraint.
_Requirement = namedtuple("_Requirement", ["req_str", "is_constraint"])


def _parse_requirements(requirements, is_constraint, base_dir=None):
    """
    A simplified version of `pip._internal.req.parse_requirements` which performs the following
    operations on the given requirements file and yields the parsed requirements.

    - Remove comments and blank lines
    - Join continued lines
    - Resolve requirements file references (e.g. '-r requirements.txt')
    - Resolve constraints file references (e.g. '-c constraints.txt')

    :param requirements: A string path to a requirements file on the local filesystem or
                         an iterable of pip requirement strings.
    :param is_constraint: Indicates the parsed requirements file is a constraint file.
    :param base_dir: If specified, resolve relative file references (e.g. '-r requirements.txt')
                     against the specified directory.
    :return: A list of ``_Requirement`` instances.

    References:
    - `pip._internal.req.parse_requirements`:
      https://github.com/pypa/pip/blob/7a77484a492c8f1e1f5ef24eaf71a43df9ea47eb/src/pip/_internal/req/req_file.py#L118
    - Requirements File Format:
      https://pip.pypa.io/en/stable/cli/pip_install/#requirements-file-format
    - Constraints Files:
      https://pip.pypa.io/en/stable/user_guide/#constraints-files
    """
    if base_dir is None:
        if isinstance(requirements, (str, Path)):
            base_dir = os.path.dirname(requirements)
            with open(requirements) as f:
                requirements = f.read().splitlines()
        else:
            base_dir = os.getcwd()

    lines = map(str.strip, requirements)
    lines = map(_strip_inline_comment, lines)
    lines = _join_continued_lines(lines)
    lines = filterfalse(_is_comment, lines)
    lines = filterfalse(_is_empty, lines)

    for line in lines:
        if _is_requirements_file(line):
            req_file = line.split(maxsplit=1)[1]
            # If `req_file` is an absolute path, `os.path.join` returns `req_file`:
            # https://docs.python.org/3/library/os.path.html#os.path.join
            abs_path = os.path.join(base_dir, req_file)
            yield from _parse_requirements(abs_path, is_constraint=False)
        elif _is_constraints_file(line):
            req_file = line.split(maxsplit=1)[1]
            abs_path = os.path.join(base_dir, req_file)
            yield from _parse_requirements(abs_path, is_constraint=True)
        else:
            yield _Requirement(line, is_constraint)


def _flatten(iterable):
    return chain.from_iterable(iterable)


# https://www.python.org/dev/peps/pep-0508/#names
_PACKAGE_NAME_REGEX = re.compile(r"^(\w+|\w+[\w._-]*\w+)")


def _get_package_name(requirement):
    m = _PACKAGE_NAME_REGEX.match(requirement)
    return m and m.group(1)


_NORMALIZE_REGEX = re.compile(r"[-_.]+")


def _normalize_package_name(pkg_name):
    """
    Normalizes a package name using the rule defined in PEP 503:
    https://www.python.org/dev/peps/pep-0503/#normalized-names
    """
    return _NORMALIZE_REGEX.sub("-", pkg_name).lower()


def _get_requires(pkg_name):
    norm_pkg_name = _normalize_package_name(pkg_name)
    if package := pkg_resources.working_set.by_key.get(norm_pkg_name):
        for req in package.requires():
            yield _normalize_package_name(req.name)


def _get_requires_recursive(pkg_name, seen_before=None):
    """
    Recursively yields both direct and transitive dependencies of the specified
    package.
    """
    norm_pkg_name = _normalize_package_name(pkg_name)
    seen_before = seen_before or {norm_pkg_name}
    for req in _get_requires(pkg_name):
        # Prevent infinite recursion due to cyclic dependencies
        if req in seen_before:
            continue
        seen_before.add(req)
        yield req
        yield from _get_requires_recursive(req, seen_before)


def _prune_packages(packages):
    """
    Prunes packages required by other packages. For example, `["scikit-learn", "numpy"]` is pruned
    to `["scikit-learn"]`.
    """
    packages = set(packages)
    requires = set(_flatten(map(_get_requires_recursive, packages)))
    # Do not exclude mlflow's dependencies
    return packages - (requires - set(_get_requires("mlflow")))


def _run_command(cmd, timeout_seconds, env=None):
    """
    Runs the specified command. If it exits with non-zero status, `MlflowException` is raised.
    """
    proc = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, env=env)
    timer = Timer(timeout_seconds, proc.kill)
    try:
        timer.start()
        stdout, stderr = proc.communicate()
        stdout = stdout.decode("utf-8")
        stderr = stderr.decode("utf-8")
        if proc.returncode != 0:
            msg = "\n".join(
                [
                    f"Encountered an unexpected error while running {cmd}",
                    f"exit status: {proc.returncode}",
                    f"stdout: {stdout}",
                    f"stderr: {stderr}",
                ]
            )
            raise MlflowException(msg)
    finally:
        if timer.is_alive():
            timer.cancel()


def _get_installed_version(package, module=None):
    """
    Obtains the installed package version using `importlib_metadata.version`. If it fails, use
    `__import__(module or package).__version__`.
    """
    try:
        version = importlib_metadata.version(package)
    except importlib_metadata.PackageNotFoundError:
        # Note `importlib_metadata.version(package)` is not necessarily equal to
        # `__import__(package).__version__`. See the example for pytorch below.
        #
        # Example
        # -------
        # $ pip install torch==1.9.0
        # $ python -c "import torch; print(torch.__version__)"
        # 1.9.0+cu102
        # $ python -c "import importlib_metadata; print(importlib_metadata.version('torch'))"
        # 1.9.0
        version = __import__(module or package).__version__

    # Strip the suffix from `dev` versions of PySpark, which are not available for installation
    # from Anaconda or PyPI
    if package == "pyspark":
        version = _strip_dev_version_suffix(version)

    return version


def _capture_imported_modules(model_uri, flavor):
    """
    Runs `_capture_modules.py` in a subprocess and captures modules imported during the model
    loading procedure.

    :param model_uri: The URI of the model.
    :param: flavor: The flavor name of the model.
    :return: A list of captured modules.
    """
    # Lazily import `_capture_module` here to avoid circular imports.
    from mlflow.utils import _capture_modules

    local_model_path = _download_artifact_from_uri(model_uri)

    process_timeout = MLFLOW_REQUIREMENTS_INFERENCE_TIMEOUT.get()

    # Run `_capture_modules.py` to capture modules imported during the loading procedure
    with tempfile.TemporaryDirectory() as tmpdir:
        output_file = os.path.join(tmpdir, "imported_modules.txt")
        # Pass the main environment variables to the subprocess for environment variable mapping
        main_env = os.environ.copy()
        # Reset the path variable from the main process so that the subprocess retains all
        # main process configuration that a user has.
        # See: ``https://github.com/mlflow/mlflow/issues/6905`` for context on minio configuration
        # resolution in a subprocess based on PATH entries.
        main_env["PATH"] = "/usr/sbin:/sbin:" + main_env["PATH"]

        _run_command(
            [
                sys.executable,
                _capture_modules.__file__,
                "--model-path",
                local_model_path,
                "--flavor",
                flavor,
                "--output-file",
                output_file,
                "--sys-path",
                json.dumps(sys.path),
            ],
            timeout_seconds=process_timeout,
            env=main_env,
        )
        with open(output_file) as f:
            return f.read().splitlines()


DATABRICKS_MODULES_TO_PACKAGES = {
    "databricks.automl": ["databricks-automl-runtime"],
    "databricks.automl_runtime": ["databricks-automl-runtime"],
    "databricks.model_monitoring": ["databricks-model-monitoring"],
}
_MODULES_TO_PACKAGES = None
_PACKAGES_TO_MODULES = None


def _init_modules_to_packages_map():
    global _MODULES_TO_PACKAGES
    if _MODULES_TO_PACKAGES is None and _PACKAGES_TO_MODULES is None:
        # Note `importlib_metada.packages_distributions` only captures packages installed into
        # Python’s site-packages directory via tools such as pip:
        # https://importlib-metadata.readthedocs.io/en/latest/using.html#using-importlib-metadata
        _MODULES_TO_PACKAGES = importlib_metadata.packages_distributions()

        # Multiple packages populate the `databricks` module namespace on Databricks; to avoid
        # bundling extraneous Databricks packages into model dependencies, we scope each module
        # to its relevant package
        _MODULES_TO_PACKAGES.update(DATABRICKS_MODULES_TO_PACKAGES)
        if "databricks" in _MODULES_TO_PACKAGES:
            _MODULES_TO_PACKAGES["databricks"] = [
                package
                for package in _MODULES_TO_PACKAGES["databricks"]
                if package not in _flatten(DATABRICKS_MODULES_TO_PACKAGES.values())
            ]

        # In Databricks, `_MODULES_TO_PACKAGES` doesn't contain pyspark since it's not installed
        # via pip or conda. To work around this issue, manually add pyspark.
        if is_in_databricks_runtime():
            _MODULES_TO_PACKAGES.update({"pyspark": ["pyspark"]})


def _init_packages_to_modules_map():
    _init_modules_to_packages_map()
    global _PACKAGES_TO_MODULES
    _PACKAGES_TO_MODULES = {}
    for module, pkg_list in _MODULES_TO_PACKAGES.items():
        for pkg_name in pkg_list:
            _PACKAGES_TO_MODULES[pkg_name] = module


# Represents the PyPI package index at a particular date
# :param date: The YYYY-MM-DD formatted string date on which the index was fetched.
# :param package_names: The set of package names in the index.
_PyPIPackageIndex = namedtuple("_PyPIPackageIndex", ["date", "package_names"])


def _load_pypi_package_index():
    pypi_index_path = pkg_resources.resource_filename(mlflow.__name__, "pypi_package_index.json")
    with open(pypi_index_path) as f:
        index_dict = json.load(f)

    return _PyPIPackageIndex(
        date=index_dict["index_date"],
        package_names=set(index_dict["package_names"]),
    )


_PYPI_PACKAGE_INDEX = None


def _infer_requirements(model_uri, flavor):
    """
    Infers the pip requirements of the specified model by creating a subprocess and loading
    the model in it to determine which packages are imported.

    :param model_uri: The URI of the model.
    :param: flavor: The flavor name of the model.
    :return: A list of inferred pip requirements.
    """
    _init_modules_to_packages_map()
    global _PYPI_PACKAGE_INDEX
    if _PYPI_PACKAGE_INDEX is None:
        _PYPI_PACKAGE_INDEX = _load_pypi_package_index()

    modules = _capture_imported_modules(model_uri, flavor)
    packages = _flatten([_MODULES_TO_PACKAGES.get(module, []) for module in modules])
    packages = set(map(_normalize_package_name, packages))
    packages = _prune_packages(packages)
    excluded_packages = [
        # Certain packages (e.g. scikit-learn 0.24.2) imports `setuptools` or `pkg_resources`
        # (a module provided by `setuptools`) to process or interact with package metadata.
        # It should be safe to exclude `setuptools` because it's rare to encounter a python
        # environment where `setuptools` is not pre-installed.
        "setuptools",
        # Exclude a package that provides the mlflow module (e.g. mlflow, mlflow-skinny).
        # Certain flavors (e.g. pytorch) import mlflow while loading a model, but mlflow should
        # not be counted as a model requirement.
        *_MODULES_TO_PACKAGES.get("mlflow", []),
    ]
    packages = packages - set(excluded_packages)
    unrecognized_packages = packages - _PYPI_PACKAGE_INDEX.package_names
    if unrecognized_packages:
        _logger.warning(
            "The following packages were not found in the public PyPI package index as of"
            " %s; if these packages are not present in the public PyPI index, you must install"
            " them manually before loading your model: %s",
            _PYPI_PACKAGE_INDEX.date,
            unrecognized_packages,
        )
    return sorted(map(_get_pinned_requirement, packages))


def _get_local_version_label(version):
    """
    Extracts a local version label from `version`.

    :param version: A version string.
    """
    try:
        return Version(version).local
    except InvalidVersion:
        return None


def _strip_local_version_label(version):
    """
    Strips a local version label in `version`.

    Local version identifiers:
    https://www.python.org/dev/peps/pep-0440/#local-version-identifiers

    :param version: A version string to strip.
    """

    class IgnoreLocal(Version):
        @property
        def local(self):
            return None

    try:
        return str(IgnoreLocal(version))
    except InvalidVersion:
        return version


def _get_pinned_requirement(package, version=None, module=None):
    """
    Returns a string representing a pinned pip requirement to install the specified package and
    version (e.g. 'mlflow==1.2.3').

    :param package: The name of the package.
    :param version: The version of the package. If None, defaults to the installed version.
    :param module: The name of the top-level module provided by the package . For example,
                   if `package` is 'scikit-learn', `module` should be 'sklearn'. If None, defaults
                   to `package`.
    """
    if version is None:
        version_raw = _get_installed_version(package, module)
        local_version_label = _get_local_version_label(version_raw)
        if local_version_label:
            version = _strip_local_version_label(version_raw)
            msg = (
                f"Found {package} version ({version_raw}) contains a local version label "
                f"(+{local_version_label}). MLflow logged a pip requirement for this package as "
                f"'{package}=={version}' without the local version label to make it "
                "installable from PyPI. To specify pip requirements containing local version "
                "labels, please use `conda_env` or `pip_requirements`."
            )
            _logger.warning(msg)

        else:
            version = version_raw

    return f"{package}=={version}"


class _MismatchedPackageInfo(NamedTuple):
    package_name: str
    installed_version: Optional[str]
    requirement: str

    def __str__(self):
        current_status = self.installed_version if self.installed_version else "uninstalled"
        return f"{self.package_name} (current: {current_status}, required: {self.requirement})"


def _check_requirement_satisfied(requirement_str):
    """
    Checks whether the current python environment satisfies the given requirement if it is parsable
    as a package name and a set of version specifiers, and returns a `_MismatchedPackageInfo`
    object containing the mismatched package name, installed version, and requirement if the
    requirement is not satisfied. Otherwise, returns None.
    """
    _init_packages_to_modules_map()
    try:
        req = pkg_resources.Requirement.parse(requirement_str)
    except Exception:
        # We reach here if the requirement string is a file path or a URL.
        # Extracting the package name from the requirement string is not trivial,
        # so we skip the check.
        return
    pkg_name = req.name

    try:
        installed_version = _get_installed_version(pkg_name, _PACKAGES_TO_MODULES.get(pkg_name))
    except ModuleNotFoundError:
        return _MismatchedPackageInfo(
            package_name=pkg_name,
            installed_version=None,
            requirement=requirement_str,
        )

    if len(req.specifier) > 0 and not req.specifier.contains(installed_version):
        return _MismatchedPackageInfo(
            package_name=pkg_name,
            installed_version=installed_version,
            requirement=requirement_str,
        )

    return None



import argparse
import sys
import json
import logging

import mlflow
from mlflow.pyfunc import scoring_server

_logger = logging.getLogger(__name__)
logging.basicConfig(level=logging.INFO)

parser = argparse.ArgumentParser()
parser.add_argument("--model-uri")
args = parser.parse_args()

_logger.info("Loading model from %s", args.model_uri)
model = mlflow.pyfunc.load_model(args.model_uri)
input_schema = model.metadata.get_input_schema()
_logger.info("Loaded model")

_logger.info("Waiting for request")
for line in sys.stdin:
    _logger.info("Received request")
    request = json.loads(line)

    _logger.info("Parsing input data")
    data = request["data"]
    data = scoring_server.infer_and_parse_json_input(data, input_schema)

    _logger.info("Making predictions")
    preds = model.predict(data)

    _logger.info("Writing predictions")
    with open(request["output_file"], "a") as f:
        scoring_server.predictions_to_json(preds, f, {"id": request["id"]})

    _logger.info("Done")



import requests
import time
import json
import tempfile
import logging
import uuid
from pathlib import Path
from abc import ABC, abstractmethod


from mlflow.pyfunc import scoring_server

from mlflow.exceptions import MlflowException
from mlflow.utils.proto_json_utils import dump_input_data
from mlflow.deployments import PredictionsResponse

_logger = logging.getLogger(__name__)


class BaseScoringServerClient(ABC):
    @abstractmethod
    def wait_server_ready(self, timeout=30, scoring_server_proc=None):
        """
        Wait until the scoring server is ready to accept requests.
        """

    @abstractmethod
    def invoke(self, data):
        """
        Invoke inference on input data. The input data must be pandas dataframe or numpy array or
        a dict of numpy arrays.
        """


class ScoringServerClient(BaseScoringServerClient):
    def __init__(self, host, port):
        self.url_prefix = f"http://{host}:{port}"

    def ping(self):
        ping_status = requests.get(url=self.url_prefix + "/ping")
        if ping_status.status_code != 200:
            raise Exception(f"ping failed (error code {ping_status.status_code})")

    def get_version(self):
        resp_status = requests.get(url=self.url_prefix + "/version")
        if resp_status.status_code != 200:
            raise Exception(f"version failed (error code {resp_status.status_code})")
        return resp_status.text

    def wait_server_ready(self, timeout=30, scoring_server_proc=None):
        begin_time = time.time()

        while True:
            time.sleep(0.3)
            try:
                self.ping()
                return
            except Exception:
                pass
            if time.time() - begin_time > timeout:
                break
            if scoring_server_proc is not None:
                return_code = scoring_server_proc.poll()
                if return_code is not None:
                    raise RuntimeError(f"Server process already exit with returncode {return_code}")
        raise RuntimeError("Wait scoring server ready timeout.")

    def invoke(self, data):
        response = requests.post(
            url=self.url_prefix + "/invocations",
            data=dump_input_data(data),
            headers={"Content-Type": scoring_server.CONTENT_TYPE_JSON},
        )
        if response.status_code != 200:
            raise Exception(
                f"Invocation failed (error code {response.status_code}, response: {response.text})"
            )
        return PredictionsResponse.from_json(response.text)


class StdinScoringServerClient(BaseScoringServerClient):
    def __init__(self, process):
        self.process = process
        self.tmpdir = Path(tempfile.mkdtemp())
        self.output_json = self.tmpdir.joinpath("output.json")

    def wait_server_ready(self, timeout=30, scoring_server_proc=None):
        return_code = self.process.poll()
        if return_code is not None:
            raise RuntimeError(f"Server process already exit with returncode {return_code}")

    def invoke(self, data):
        """
        Invoke inference on input data. The input data must be pandas dataframe or numpy array or
        a dict of numpy arrays.
        """
        if not self.output_json.exists():
            self.output_json.touch()

        request_id = str(uuid.uuid4())
        request = {
            "id": request_id,
            "data": dump_input_data(data),
            "output_file": str(self.output_json),
        }
        self.process.stdin.write(json.dumps(request) + "\n")
        self.process.stdin.flush()

        begin_time = time.time()
        while True:
            _logger.info("Waiting for scoring to complete...")
            try:
                with self.output_json.open(mode="r+") as f:
                    resp = PredictionsResponse.from_json(f.read())
                    if resp.get("id") == request_id:
                        f.truncate(0)
                        return resp
            except Exception as e:
                _logger.debug("Exception while waiting for scoring to complete: %s", e)
            if time.time() - begin_time > 60:
                raise MlflowException("Scoring timeout")
            time.sleep(1)



class User:
    def __init__(
        self,
        username,
        password_hash,
        is_admin,
        experiment_permissions=None,
        registered_model_permissions=None,
    ):
        self._username = username
        self._password_hash = password_hash
        self._is_admin = is_admin
        self._experiment_permissions = experiment_permissions
        self._registered_model_permissions = registered_model_permissions

    @property
    def username(self):
        return self._username

    @property
    def password_hash(self):
        return self._password_hash

    @property
    def is_admin(self):
        return self._is_admin

    @is_admin.setter
    def is_admin(self, is_admin):
        self._is_admin = is_admin

    @property
    def experiment_permissions(self):
        return self._experiment_permissions

    @experiment_permissions.setter
    def experiment_permissions(self, experiment_permissions):
        self._experiment_permissions = experiment_permissions

    @property
    def registered_model_permissions(self):
        return self._registered_model_permissions

    @registered_model_permissions.setter
    def registered_model_permissions(self, registered_model_permissions):
        self._registered_model_permissions = registered_model_permissions


class ExperimentPermission:
    def __init__(
        self,
        experiment_id,
        user_id,
        permission,
    ):
        self._experiment_id = experiment_id
        self._user_id = user_id
        self._permission = permission

    @property
    def experiment_id(self):
        return self._experiment_id

    @property
    def user_id(self):
        return self._user_id

    @property
    def permission(self):
        return self._permission

    @permission.setter
    def permission(self, permission):
        self._permission = permission


class RegisteredModelPermission:
    def __init__(
        self,
        name,
        user_id,
        permission,
    ):
        self._name = name
        self._user_id = user_id
        self._permission = permission

    @property
    def name(self):
        return self.name

    @property
    def user_id(self):
        return self._user_id

    @property
    def permission(self):
        return self._permission

    @permission.setter
    def permission(self, permission):
        self._permission = permission
